import { useQuery } from "@tanstack/react-query";
import { useState, useMemo, useEffect } from "react";
import { Link, useLocation } from "wouter";
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { Avatar, AvatarFallback } from "@/components/ui/avatar";
import { Badge } from "@/components/ui/badge";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { FamilyMemberCard } from "@/components/family-member-card";
import { NutritionChart } from "@/components/nutrition-chart";
import { ProgressCircle } from "@/components/progress-circle";
import { MealCard } from "@/components/meal-card";
import { NutritionCoach } from "@/components/nutrition-coach";
import { Skeleton } from "@/components/ui/skeleton";

import { SmartMealPlanGenerator } from "@/components/smart-meal-plan-generator";
import { BriskLifeyLogo } from "@/components/brisklifey-logo";
import { 
  Users, 
  Plus, 
  Apple, 
  Target, 
  BarChart3, 
  FileText, 
  ChefHat,
  Brain,
  User,
  LogOut,
  BookOpen,
  TrendingUp,
  MessageSquare,
  Utensils,
  Dumbbell,
  Droplets,
  Crown
} from "lucide-react";
import { useAuth } from "@/hooks/useAuth";
import { trackDashboardVisit } from "@/components/smart-back-navigation";
import { queryClient } from "@/lib/queryClient";
import { useTutorial } from "@/hooks/useTutorial";
import { TutorialOverlay } from "@/components/tutorial-overlay";


function Dashboard() {
  const { user } = useAuth();
  const [, setLocation] = useLocation();
  const [selectedMemberIdx, setSelectedMemberIdx] = useState(0);
  
  // Tutorial system with proper backend integration
  const { 
    shouldShowTutorial, 
    incrementLoginCount, 
    completeTutorial, 
    skipTutorial 
  } = useTutorial();
  
  // Increment login count when dashboard loads
  useEffect(() => {
    if (user) {
      incrementLoginCount();
    }
  }, [user, incrementLoginCount]);
  
  // Track dashboard visit for smart navigation
  trackDashboardVisit();

  const { data: familyMembers = [], isLoading: familyMembersLoading, error: familyMembersError } = useQuery({
    queryKey: ["/api/family-members"],
    enabled: !!user,
    retry: 2,
    staleTime: 2 * 60 * 1000, // 2 minutes cache
    gcTime: 5 * 60 * 1000, // 5 minutes garbage collection
    refetchOnMount: false, // Don't refetch on mount
    refetchOnWindowFocus: false, // Don't refetch on focus
  });

  const familyMembersArray = useMemo(() => {
    return Array.isArray(familyMembers) ? familyMembers : [];
  }, [familyMembers]);
  
  const selectedMember = useMemo(() => 
    familyMembersArray[selectedMemberIdx] || familyMembersArray[0],
    [familyMembersArray, selectedMemberIdx]
  );

  const { data: mealEntries = [], isLoading: mealEntriesLoading, error: mealEntriesError } = useQuery({
    queryKey: ["/api/meal-entries", selectedMember?.id],
    enabled: !!selectedMember?.id && !familyMembersLoading,
    retry: 1,
    staleTime: 10 * 60 * 1000, // 10 minutes to reduce API calls
    refetchInterval: false, // Disable automatic refetching
    refetchOnWindowFocus: false,
    notifyOnChangeProps: ['data', 'error'], // Only re-render on data/error changes
  });

  const { data: nutritionGoals = [], isLoading: goalsLoading, error: goalsError } = useQuery({
    queryKey: ["/api/nutrition-goals", selectedMember?.id],
    enabled: !!selectedMember?.id && !familyMembersLoading,
    retry: 1,
    staleTime: 15 * 60 * 1000, // 15 minutes for goals
    refetchInterval: false, // Disable automatic refetching
    refetchOnWindowFocus: false,
    notifyOnChangeProps: ['data', 'error'], // Only re-render on data/error changes
  });

  // Show skeleton loading state for better UX
  if (familyMembersLoading) {
    return (
      <div className="min-h-screen bg-gradient-to-br from-fresh-green/5 via-white to-warm-orange/5">
        <div className="container mx-auto px-4 py-6">
          <div className="bg-white rounded-lg border border-neutral-200 p-4 sm:p-6 mb-6 shadow-sm">
            <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4">
              <div className="flex items-center space-x-3">
                <Skeleton className="w-12 h-12 rounded-lg" />
                <div>
                  <Skeleton className="h-6 w-32 mb-2" />
                  <Skeleton className="h-4 w-24" />
                </div>
              </div>
              <Skeleton className="h-9 w-[200px]" />
            </div>
          </div>
          <div className="text-center py-8">
            <div className="animate-pulse">
              <div className="text-lg text-gray-600 mb-2">Loading your family dashboard...</div>
              <div className="text-sm text-gray-500">Setting up your personalized nutrition experience</div>
            </div>
          </div>
          <div className="grid grid-cols-2 lg:grid-cols-3 gap-3 sm:gap-4 w-full max-w-6xl mx-auto mb-6">
            {[1, 2, 3, 4, 5, 6].map((i) => (
              <Card key={i} className="h-32">
                <CardContent className="p-4 text-center h-full flex flex-col justify-center items-center">
                  <Skeleton className="w-12 h-12 rounded-lg mb-2" />
                  <Skeleton className="h-4 w-20" />
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </div>
    );
  }

  // Continue with dashboard rendering regardless of minor errors
  const dailyTotals = Array.isArray(mealEntries) ? mealEntries.reduce(
    (totals: any, entry: any) => {
      if (entry.foodItem) {
        const calories = parseFloat(entry.foodItem.caloriesPerServing || "0");
        const protein = parseFloat(entry.foodItem.protein || "0");
        const carbs = parseFloat(entry.foodItem.carbs || "0");
        const fat = parseFloat(entry.foodItem.fat || "0");

        totals.calories += calories;
        totals.protein += protein;
        totals.carbs += carbs;
        totals.fat += fat;
      }
      return totals;
    },
    { calories: 0, protein: 0, carbs: 0, fat: 0 }
  ) : { calories: 0, protein: 0, carbs: 0, fat: 0 };

  const calorieGoal = Array.isArray(nutritionGoals) ? 
    nutritionGoals.find((goal: any) => goal.nutrientType === "calories") : undefined;
  const proteinGoal = Array.isArray(nutritionGoals) ? 
    nutritionGoals.find((goal: any) => goal.nutrientType === "protein") : undefined;

  const calorieProgress = calorieGoal ? 
    Math.min((dailyTotals.calories / parseFloat(calorieGoal.targetValue)) * 100, 100) : 0;
  const proteinProgress = proteinGoal ? 
    Math.min((dailyTotals.protein / parseFloat(proteinGoal.targetValue)) * 100, 100) : 0;

  return (
    <div className="min-h-screen bg-gradient-to-br from-fresh-green/5 via-white to-warm-orange/5">
      <div className="container mx-auto px-4 py-6 relative">
        {/* Top Right Controls - Now Inside Container */}
        <div className="absolute top-6 right-4 z-10 flex items-center space-x-2">
          <Link href="/contact?source=dashboard">
            <Button data-tutorial="contact" size="sm" variant="ghost" className="w-9 h-9 p-0 bg-white/90 shadow-sm border border-neutral-200/50" title="Contact Us">
              <MessageSquare className="h-4 w-4" />
            </Button>
          </Link>
          <Link href="/settings">
            <Button data-tutorial="settings" size="sm" variant="ghost" className="w-9 h-9 p-0 bg-white/90 shadow-sm border border-neutral-200/50">
              <User className="h-4 w-4" />
            </Button>
          </Link>
          
          <Button 
            size="sm" 
            variant="ghost"
            className="w-9 h-9 p-0 text-red-500 hover:text-red-600 hover:bg-red-50 bg-white/90 shadow-sm border border-neutral-200/50"
            onClick={async () => {
              try {
                // Set logout flag to prevent landing page redirect
                localStorage.setItem('logout_in_progress', 'true');
                
                // Call logout API
                await fetch('/api/auth/logout', { 
                  method: 'POST',
                  credentials: 'include',
                  headers: {
                    'Content-Type': 'application/json'
                  }
                });
                
                // Clear cache and storage
                queryClient.removeQueries();
                queryClient.invalidateQueries();
                queryClient.clear();
                queryClient.cancelQueries();
                localStorage.removeItem('react-query-cache');
                sessionStorage.clear();
                
                // Wait briefly then redirect
                await new Promise(resolve => setTimeout(resolve, 50));
                window.location.replace('/');
                
              } catch (error) {
                // Force logout even on API failure
                localStorage.setItem('logout_in_progress', 'true');
                queryClient.clear();
                sessionStorage.clear();
                window.location.replace('/');
              }
            }}
          >
            <LogOut className="h-4 w-4" />
          </Button>
        </div>
        <div className="flex flex-col lg:flex-row gap-6">
          {/* Main Content */}
          <div className="flex-1 space-y-6">
            {/* Professional Dashboard Header - No HIPAA Test */}
            <div className="bg-white rounded-lg border border-neutral-200 p-4 sm:p-6 mb-6 shadow-sm">
              {/* Responsive Layout */}
              <div className="flex flex-col sm:flex-row sm:items-center sm:justify-between gap-4">
                {/* Brand */}
                <div className="flex items-center space-x-3 dashboard-logo">
                  <div className="w-12 h-12 flex items-center justify-center">
                    <img 
                      src="/attached_assets/d6964776-9331-4415-9e96-cb5718106591_1750953634652.png" 
                      alt="BriskLifey Logo" 
                      className="w-12 h-12 object-contain"
                    />
                  </div>
                  <div>
                    <h1 className="text-xl sm:text-2xl font-bold tracking-tight">
                      <span style={{color: '#2563eb'}}>BRISK</span><span style={{color: '#16a34a'}}>LIFE</span><span style={{color: '#ea580c'}}>Y</span>
                    </h1>
                    <p className="text-neutral-500 text-sm">Family Nutrition Hub</p>
                  </div>
                </div>

                {/* Family Selector Only */}
                <div className="min-w-0 sm:min-w-[200px]">
                  {familyMembersArray.length > 0 ? (
                    <Select 
                      value={selectedMemberIdx.toString()} 
                      onValueChange={(value) => setSelectedMemberIdx(parseInt(value))}
                    >
                      <SelectTrigger className="h-9 border-neutral-200">
                        <div className="flex items-center gap-2">
                          <Users className="h-4 w-4 text-neutral-500" />
                          <SelectValue />
                        </div>
                      </SelectTrigger>
                      <SelectContent>
                        {familyMembersArray.map((member: any, idx: number) => (
                          <SelectItem key={member.id} value={idx.toString()}>
                            <div className="flex items-center gap-2">
                              <Avatar className="h-4 w-4">
                                <AvatarFallback className="text-xs bg-fresh-green text-white">
                                  {member.name?.charAt(0)?.toUpperCase() || "?"}
                                </AvatarFallback>
                              </Avatar>
                              <span className="text-sm">{member.name}</span>
                            </div>
                          </SelectItem>
                        ))}
                      </SelectContent>
                    </Select>
                  ) : (
                    <div className="text-sm text-neutral-500 px-3 py-1.5 border rounded-md bg-neutral-50">
                      No members yet
                    </div>
                  )}
                </div>
              </div>
            </div>

            {/* Quick Actions Grid - Enhanced Layout for 5 Features */}
            <div className="grid grid-cols-2 lg:grid-cols-3 gap-3 sm:gap-4 w-full max-w-6xl mx-auto">
              <Link href="/meal-plan-generator">
                <Card data-tutorial="meal-plans" className="cursor-pointer hover:shadow-lg transition-all duration-200 border-2 hover:border-fresh-green/20 h-32">
                  <CardContent className="p-4 text-center h-full flex flex-col justify-center items-center">
                    <div className="w-12 h-12 bg-fresh-green/10 rounded-lg flex items-center justify-center mx-auto mb-2">
                      <ChefHat className="h-6 w-6 text-fresh-green" />
                    </div>
                    <h3 className="font-semibold text-sm text-neutral-800 leading-tight">Smart<br/>Meal<br/>Planner</h3>
                  </CardContent>
                </Card>
              </Link>

              <Link href="/workout-exercise">
                <Card className="cursor-pointer hover:shadow-lg transition-all duration-200 border-2 hover:border-warm-orange/20 h-32">
                  <CardContent className="p-4 text-center h-full flex flex-col justify-center items-center">
                    <div className="w-12 h-12 bg-warm-orange/10 rounded-lg flex items-center justify-center mx-auto mb-2">
                      <Dumbbell className="h-6 w-6 text-warm-orange" />
                    </div>
                    <h3 className="font-semibold text-sm text-neutral-800 leading-tight">Workout &<br/>Exercise</h3>
                  </CardContent>
                </Card>
              </Link>

              <Link href="/family-members">
                <Card data-tutorial="family-profiles" className="cursor-pointer hover:shadow-lg transition-all duration-200 border-2 hover:border-purple-500/20 h-32">
                  <CardContent className="p-4 text-center h-full flex flex-col justify-center items-center">
                    <div className="w-12 h-12 bg-purple-500/10 rounded-lg flex items-center justify-center mx-auto mb-2">
                      <Users className="h-6 w-6 text-purple-500" />
                    </div>
                    <h3 className="font-semibold text-sm text-neutral-800 leading-tight">Family<br/>Profiles</h3>
                  </CardContent>
                </Card>
              </Link>

              <Link href="/analytics">
                <Card className="cursor-pointer hover:shadow-lg transition-all duration-200 border-2 hover:border-ocean-blue/20 h-32">
                  <CardContent className="p-4 text-center h-full flex flex-col justify-center items-center">
                    <div className="w-12 h-12 bg-ocean-blue/10 rounded-lg flex items-center justify-center mx-auto mb-2">
                      <BarChart3 className="h-6 w-6 text-ocean-blue" />
                    </div>
                    <h3 className="font-semibold text-sm text-neutral-800 leading-tight">Health<br/>Analytics</h3>
                  </CardContent>
                </Card>
              </Link>

              <Link href="/pricing">
                <Card className="cursor-pointer hover:shadow-lg transition-all duration-200 border-2 hover:border-yellow-500/20 h-32 bg-gradient-to-br from-yellow-50 to-yellow-100">
                  <CardContent className="p-4 text-center h-full flex flex-col justify-center items-center">
                    <div className="w-12 h-12 bg-yellow-500/10 rounded-lg flex items-center justify-center mx-auto mb-2">
                      <Crown className="h-6 w-6 text-yellow-600" />
                    </div>
                    <h3 className="font-semibold text-sm text-neutral-800 leading-tight">Upgrade<br/>Plan</h3>
                  </CardContent>
                </Card>
              </Link>

              <Link href="/recipes">
                <Card className="cursor-pointer hover:shadow-lg transition-all duration-200 border-2 hover:border-emerald-500/20 h-32">
                  <CardContent className="p-4 text-center h-full flex flex-col justify-center items-center">
                    <div className="w-12 h-12 bg-emerald-500/10 rounded-lg flex items-center justify-center mx-auto mb-2">
                      <BookOpen className="h-6 w-6 text-emerald-500" />
                    </div>
                    <h3 className="font-semibold text-sm text-neutral-800 leading-tight">Recipe<br/>Collection</h3>
                  </CardContent>
                </Card>
              </Link>

              <Link href="/hydration-tracker">
                <Card className="cursor-pointer hover:shadow-lg transition-all duration-200 border-2 hover:border-cyan-500/20 h-32">
                  <CardContent className="p-4 text-center h-full flex flex-col justify-center items-center">
                    <div className="w-12 h-12 bg-cyan-500/10 rounded-lg flex items-center justify-center mx-auto mb-2">
                      <Droplets className="h-6 w-6 text-cyan-500" />
                    </div>
                    <h3 className="font-semibold text-sm text-neutral-800 leading-tight">Hydration<br/>Tracker</h3>
                  </CardContent>
                </Card>
              </Link>
            </div>

            {/* AI Nutrition Coach */}
            <Card data-tutorial="ai-coach" className="mb-6">
              <CardHeader className="pb-3">
                <CardTitle className="flex items-center gap-2 text-lg">
                  <Brain className="h-5 w-5 text-ocean-blue" />
                  AI Nutrition & Mental Wellbeing Coach
                </CardTitle>
                <p className="text-sm text-neutral-600">Get comprehensive nutrition and mental wellness support for your family member</p>
              </CardHeader>
              <CardContent className="pt-0">
                <NutritionCoach userProfile={selectedMember} selectedMember={selectedMember} />
              </CardContent>
            </Card>

            {/* Smart Meal Planner */}
            <Card className="mb-6">
              <CardHeader className="pb-3">
                <CardTitle className="flex items-center gap-2 text-lg">
                  <ChefHat className="h-5 w-5 text-fresh-green" />
                  Smart Meal Planner
                </CardTitle>
                <p className="text-sm text-neutral-600">Generate personalized meal plans for your family member</p>
              </CardHeader>
              <CardContent className="pt-0">
                <SmartMealPlanGenerator selectedMember={selectedMember} />
              </CardContent>
            </Card>

            {/* Smart Grocery Lists Card */}
            <Card className="mb-6 hover:shadow-lg transition-shadow cursor-pointer group" onClick={() => setLocation("/grocery-lists")}>
              <CardHeader className="pb-3">
                <CardTitle className="flex items-center gap-2 text-lg">
                  <ChefHat className="h-5 w-5 text-emerald-500" />
                  Smart Grocery Lists
                </CardTitle>
                <p className="text-sm text-neutral-600">AI-generated shopping lists based on your family's needs and budget</p>
              </CardHeader>
              <CardContent className="pt-0">
                <div className="text-center p-6">
                  <div className="w-12 h-12 bg-gradient-to-br from-emerald-500 to-teal-500 rounded-full flex items-center justify-center mx-auto mb-4 group-hover:scale-110 transition-transform">
                    <ChefHat className="h-6 w-6 text-white" />
                  </div>
                  <p className="text-sm text-gray-600">Create smart grocery lists optimized for your family's nutritional needs</p>
                </div>
              </CardContent>
            </Card>


          </div>

          {/* Sidebar */}
          <div className="lg:w-80 space-y-4">
            {/* Family Members */}
            <Card>
              <CardHeader className="pb-3">
                <CardTitle className="text-lg">Family Members</CardTitle>
              </CardHeader>
              <CardContent className="pt-0">
                <div className="space-y-3">
                  {familyMembersArray.length > 0 ? (
                    familyMembersArray.map((member: any) => (
                      <FamilyMemberCard
                        key={member.id}
                        member={member}
                        compact={true}
                      />
                    ))
                  ) : (
                    <div className="text-center py-4">
                      <Users className="h-8 w-8 text-neutral-400 mx-auto mb-2" />
                      <p className="text-sm text-neutral-600">No family members yet</p>
                      <Link href="/family-members">
                        <Button className="mt-2 bg-green-600 hover:bg-green-700 text-white font-bold px-6 py-2 shadow-lg">
                          <Plus className="h-4 w-4 mr-2" />
                          Add Member
                        </Button>
                      </Link>
                    </div>
                  )}
                </div>
              </CardContent>
            </Card>


          </div>
        </div>
      </div>
      
      {/* Tutorial System - Backend Integrated Version */}
      {shouldShowTutorial && (
        <div className="fixed inset-0 z-50 flex items-center justify-center">
          {/* Backdrop */}
          <div className="absolute inset-0 bg-black/50 backdrop-blur-sm" />
          
          {/* Tutorial Content */}
          <div className="relative bg-white rounded-xl shadow-2xl p-6 mx-4 max-w-md w-full border border-gray-200">
            <div className="text-center">
              <h2 className="text-xl font-bold text-gray-900 mb-4">
                Welcome to BriskLifey! 👋
              </h2>
              <p className="text-gray-600 mb-6">
                Let's take a quick tour of the key features to help you get started with family nutrition tracking.
              </p>
              
              {/* Tutorial Steps */}
              <div className="space-y-4 text-left">
                <div className="flex items-start gap-3 p-3 bg-fresh-green/10 rounded-lg border border-fresh-green/20">
                  <Users className="h-5 w-5 text-fresh-green mt-0.5" />
                  <div>
                    <h3 className="font-semibold text-gray-900">Family Members</h3>
                    <p className="text-sm text-gray-600">Add and manage your family profiles with health goals and dietary preferences.</p>
                  </div>
                </div>
                
                <div className="flex items-start gap-3 p-3 bg-ocean-blue/10 rounded-lg border border-ocean-blue/20">
                  <Utensils className="h-5 w-5 text-ocean-blue mt-0.5" />
                  <div>
                    <h3 className="font-semibold text-gray-900">Smart Meal Planner</h3>
                    <p className="text-sm text-gray-600">Generate personalized meal plans based on your family's needs and medical conditions.</p>
                  </div>
                </div>
                
                <div className="flex items-start gap-3 p-3 bg-warm-orange/10 rounded-lg border border-warm-orange/20">
                  <Brain className="h-5 w-5 text-warm-orange mt-0.5" />
                  <div>
                    <h3 className="font-semibold text-gray-900">AI Nutrition Coach</h3>
                    <p className="text-sm text-gray-600">Get personalized nutrition advice and answers to your health questions.</p>
                  </div>
                </div>
              </div>
              
              {/* Action Buttons */}
              <div className="flex gap-3 mt-6">
                <Button 
                  variant="outline" 
                  onClick={skipTutorial}
                  className="flex-1"
                >
                  Skip Tour
                </Button>
                <Button 
                  onClick={completeTutorial}
                  className="flex-1 bg-fresh-green hover:bg-fresh-green/90"
                >
                  Got It!
                </Button>
              </div>
            </div>
          </div>
        </div>
      )}
    </div>
  );
}

export default Dashboard;